@@ -1563,16 +1563,16 @@ class Line(sequence_ordered(), ModelSQL, ModelView):
     def get_from_location(self, name):
         if (self.quantity or 0) >= 0:
             if self.purchase.party.supplier_location:
-                return self.purchase.party.supplier_location.id
+                return self.purchase.party.supplier_location
         elif self.purchase.return_from_location:
-            return self.purchase.return_from_location.id
+            return self.purchase.return_from_location
 
     def get_to_location(self, name):
         if (self.quantity or 0) >= 0:
             if self.purchase.warehouse:
-                return self.purchase.warehouse.input_location.id
+                return self.purchase.warehouse.input_location
         elif self.purchase.party.supplier_location:
-            return self.purchase.party.supplier_location.id
+            return self.purchase.party.supplier_location
 
     @fields.depends('moves', methods=['planned_delivery_date'])
     def on_change_with_delivery_date(self, name=None):
@@ -1773,9 +1773,12 @@ class Line(sequence_ordered(), ModelSQL, ModelView):
             if invoice_line.type != 'line':
                 continue
             if invoice_line not in skips:
-                quantity += Uom.compute_qty(
-                    invoice_line.unit or self.unit, invoice_line.quantity,
-                    self.unit)
+                if self.unit:
+                    quantity += Uom.compute_qty(
+                        invoice_line.unit or self.unit, invoice_line.quantity,
+                        self.unit)
+                else:
+                    quantity += invoice_line.quantity
         return quantity
 
     def _get_invoice_line_moves(self):
